@@ -1,4 +1,4 @@
-from . import ccddata  # noqa
+from . import nddata  # noqa
 from . import regions  # noqa
 from . import spectral_cube  # noqa
 from . import spectrum1d  # noqa
